@@ -5,20 +5,29 @@ Created on 2015-8-8
 @author: cheng.li
 """
 
+from PyFin.Analysis.TechnicalAnalysis.StatelessTechnicalAnalysers import SecurityLatestValueHolder
+
 from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingMax
 from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingMinimum
 from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingSum
+from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingVariance
 from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingCountedPositive
 from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingPositiveAverage
+from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingCountedNegative
+from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingNegativeAverage
 from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingHistoricalWindow
 from PyFin.Analysis.TechnicalAnalysis.StatefulTechnicalAnalysers import SecurityMovingLogReturn
 
-__all__ = ['SecurityMovingAverage',
+__all__ = ['SecurityLatestValueHolder',
+           'SecurityMovingAverage',
            'SecurityMovingMax',
            'SecurityMovingMinimum',
            'SecurityMovingSum',
+           'SecurityMovingVariance',
            'SecurityMovingCountedPositive',
            'SecurityMovingPositiveAverage',
+           'SecurityMovingCountedNegative',
+           'SecurityMovingNegativeAverage',
            'SecurityMovingHistoricalWindow',
            'SecurityMovingLogReturn']
