@@ -68,8 +68,7 @@ class TestStatelessAccumulators(unittest.TestCase):
             calculated = mm.result()
 
             if i == 0:
-                with self.assertRaises(ArithmeticError):
-                    _ = mm2.result()
+                self.assertTrue(np.isnan(mm2.result()))
 
             self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
                                                              "expected var:   {1:f}\n"
@@ -88,8 +87,7 @@ class TestStatelessAccumulators(unittest.TestCase):
         for i, (openPrice, closePrice) in enumerate(zip(self.samplesOpen, self.samplesClose)):
             mm.push(dict(open=openPrice, close=closePrice))
             if i == 0:
-                with self.assertRaises(ArithmeticError):
-                    _ = mm.result()
+                self.assertTrue(np.isnan(mm.result()))
             if i >= 1:
                 expected = np.corrcoef(self.samplesOpen[:i + 1], self.samplesClose[:i + 1])[0, 1]
                 calculated = mm.result()
